pub struct GitClient { /* private fields */ }Expand description
Git repository client using system git CLI.
Implementations
Sourceimpl GitClient
impl GitClient
Sourcepub fn detect(path: &Path) -> Result<Self>
pub fn detect(path: &Path) -> Result<Self>
Detect if the given path is inside a git repository. Returns a GitClient rooted at the repository root.
Sourcepub fn file_churn(&self, since: &str) -> Result<Vec<FileChurn>>
pub fn file_churn(&self, since: &str) -> Result<Vec<FileChurn>>
Get file change frequency within the given time window.
since is passed directly to git log --since, e.g. “90 days ago”, “2025-01-01”.
Sourcepub fn commit_count(&self, since: &str) -> Result<usize>
pub fn commit_count(&self, since: &str) -> Result<usize>
Get total commit count in the given time window.