TokenMatch

Struct TokenMatch 

pub struct TokenMatch {
    pub token_type: TokenType,
    pub close: Option<Vec<u8>>,
    pub advance: usize,
}
Result of a successful trie match.

Note: advance is set automatically by TokenTrie::insert() based on the pattern length. Any value provided by the caller will be overwritten.

Fields

token_type: TokenTypeclose: Option<Vec<u8>>

Closing byte sequence (e.g., */ for block comments, " for strings). None for line comments (they end at newline).

advance: usize

How many bytes to advance past the matched token (set by insert).